"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InboundMessageContext = void 0;
const error_1 = require("../../error");
class InboundMessageContext {
    constructor(message, context = {}) {
        this.message = message;
        this.recipientVerkey = context.recipientVerkey;
        if (context.connection) {
            this.connection = context.connection;
            // TODO: which senderkey should we prioritize
            // Or should we throw an error when they don't match?
            this.senderVerkey = context.connection.theirKey || context.senderVerkey || undefined;
        }
        else if (context.senderVerkey) {
            this.senderVerkey = context.senderVerkey;
        }
    }
    /**
     * Assert the inbound message has a ready connection associated with it.
     *
     * @throws {AriesFrameworkError} if there is no connection or the connection is not ready
     */
    assertReadyConnection() {
        if (!this.connection) {
            throw new error_1.AriesFrameworkError(`No connection associated with incoming message ${this.message.type}`);
        }
        // Make sure connection is ready
        this.connection.assertReady();
        return this.connection;
    }
}
exports.InboundMessageContext = InboundMessageContext;
//# sourceMappingURL=InboundMessageContext.js.map