"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RequestPresentationHandler = void 0;
const helpers_1 = require("../../../agent/helpers");
const messages_1 = require("../messages");
class RequestPresentationHandler {
    constructor(proofService, agentConfig, proofResponseCoordinator) {
        this.supportedMessages = [messages_1.RequestPresentationMessage];
        this.proofService = proofService;
        this.agentConfig = agentConfig;
        this.proofResponseCoordinator = proofResponseCoordinator;
    }
    async handle(messageContext) {
        const proofRecord = await this.proofService.processRequest(messageContext);
        if (this.proofResponseCoordinator.shouldAutoRespondToRequest(proofRecord)) {
            return await this.createPresentation(proofRecord, messageContext);
        }
    }
    async createPresentation(proofRecord, messageContext) {
        var _a, _b;
        const indyProofRequest = (_a = proofRecord.requestMessage) === null || _a === void 0 ? void 0 : _a.indyProofRequest;
        this.agentConfig.logger.info(`Automatically sending presentation with autoAccept on ${this.agentConfig.autoAcceptProofs}`);
        if (!messageContext.connection) {
            this.agentConfig.logger.error('No connection on the messageContext');
            return;
        }
        if (!indyProofRequest) {
            return;
        }
        const retrievedCredentials = await this.proofService.getRequestedCredentialsForProofRequest(indyProofRequest, (_b = proofRecord.proposalMessage) === null || _b === void 0 ? void 0 : _b.presentationProposal);
        const requestedCredentials = this.proofService.autoSelectCredentialsForProofRequest(retrievedCredentials);
        const { message } = await this.proofService.createPresentation(proofRecord, requestedCredentials);
        return helpers_1.createOutboundMessage(messageContext.connection, message);
    }
}
exports.RequestPresentationHandler = RequestPresentationHandler;
//# sourceMappingURL=RequestPresentationHandler.js.map