import type { PackedMessage, UnpackedMessageContext } from '../types';
import type { Buffer } from '../utils/buffer';
import type { Wallet, DidInfo } from './Wallet';
import type { default as Indy, Did, DidConfig, LedgerRequest, Verkey, WalletConfig, WalletCredentials, WalletQuery, WalletRecord, WalletRecordOptions, WalletSearchOptions } from 'indy-sdk';
import { AgentConfig } from '../agent/AgentConfig';
export interface IndyOpenWallet {
    walletHandle: number;
    masterSecretId: string;
    walletConfig: WalletConfig;
    walletCredentials: WalletCredentials;
}
export declare class IndyWallet implements Wallet {
    private openWalletInfo?;
    private logger;
    private publicDidInfo;
    private indy;
    constructor(agentConfig: AgentConfig);
    get isInitialized(): boolean;
    get publicDid(): DidInfo | undefined;
    get walletHandle(): number;
    get masterSecretId(): string;
    initialize(walletConfig: WalletConfig, walletCredentials: WalletCredentials): Promise<void>;
    /**
     * @throws {WalletDuplicateError} if the wallet already exists
     * @throws {WalletError} if another error occurs
     */
    create(walletConfig: WalletConfig, walletCredentials: WalletCredentials): Promise<void>;
    /**
     * @throws {WalletNotFoundError} if the wallet does not exist
     * @throws {WalletError} if another error occurs
     */
    open(walletConfig: WalletConfig, walletCredentials: WalletCredentials): Promise<void>;
    /**
     * @throws {WalletNotFoundError} if the wallet does not exist
     * @throws {WalletError} if another error occurs
     */
    delete(): Promise<void>;
    /**
     * @throws {WalletError} if the wallet is already closed or another error occurs
     */
    close(): Promise<void>;
    /**
     * Create master secret with specified id in currently opened wallet.
     *
     * If a master secret by this id already exists in the current wallet, the method
     * will return without doing anything.
     *
     * @throws {WalletError} if an error occurs
     */
    private createMasterSecret;
    initPublicDid(didConfig: DidConfig): Promise<void>;
    createDid(didConfig?: DidConfig): Promise<[Did, Verkey]>;
    pack(payload: Record<string, unknown>, recipientKeys: Verkey[], senderVk: Verkey): Promise<PackedMessage>;
    unpack(messagePackage: PackedMessage): Promise<UnpackedMessageContext>;
    sign(data: Buffer, verkey: Verkey): Promise<Buffer>;
    verify(signerVerkey: Verkey, data: Buffer, signature: Buffer): Promise<boolean>;
    addWalletRecord(type: string, id: string, value: string, tags: Record<string, string>): Promise<void>;
    updateWalletRecordValue(type: string, id: string, value: string): Promise<void>;
    updateWalletRecordTags(type: string, id: string, tags: Record<string, string>): Promise<void>;
    deleteWalletRecord(type: string, id: string): Promise<void>;
    search(type: string, query: WalletQuery, options: WalletSearchOptions): Promise<AsyncGenerator<Indy.WalletRecord, void, unknown>>;
    getWalletRecord(type: string, id: string, options: WalletRecordOptions): Promise<WalletRecord>;
    signRequest(myDid: Did, request: LedgerRequest): Promise<Indy.SignedLedgerRequest>;
    generateNonce(): Promise<string>;
}
